<?php
namespace EzSystems\PetarBundle\Command;
 
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Input\InputArgument;

use eZ\Publish\API\Repository\Repository;
 
use eZ\Publish\API\Repository\Values\Content\LocationQuery;
use eZ\Publish\API\Repository\Values\Content\Query\Criterion;


class PetarCommand extends \Symfony\Bundle\FrameworkBundle\Command\ContainerAwareCommand
{
    /**
     * Configures the command
     */
    protected function configure()
    {
        $this->setName( 'ezpublish:petartest' );
    }
 
    /**
     * Executes the command
     * @param InputInterface $input
     * @param OutputInterface $output
     */
    protected function execute( InputInterface $input, OutputInterface $output )
    {

        $searchHandler = $this->getContainer()->get( 'ezpublish.spi.search' );
        self::testCreateLocation();
        self::testMoveSubtree( $searchHandler );

    }

    protected function testCreateLocation()
    {
        $repository = $this->getContainer()->get( 'ezpublish.api.repository' );
        $locationService = $repository->getLocationService();
        $contentService = $repository->getContentService();
        $searchService = $repository->getSearchService();

        $userService = $repository->getUserService();
        $adminUser = $userService->loadUser( 14 );
        $repository->setCurrentUser( $adminUser );

//        $rootLocationId = 2;

        $membersContentId = 11;
        $membersContentInfo = $contentService->loadContentInfo($membersContentId);

//        $locationCreateStruct = $locationService->newLocationCreateStruct($rootLocationId);
//        $membersLocation = $locationService->createLocation($membersContentInfo, $locationCreateStruct);
  
        $membersLocations = $locationService->loadLocations($membersContentInfo);
        $membersLocation = $membersLocations[0];
        
//      $this->refreshSearch($repository);
        
        // Found Location
        $criterion = new Criterion\LocationId($membersLocation->id);
        $query = new LocationQuery(array('filter' => $criterion));
        $result = $searchService->findLocations($query);

        //$this->assertEquals(1, $result->totalCount);
        //$this->assertEquals($membersLocation->id, $result->searchHits[0]->valueObject->id);
        $result->totalCount == 1 ? printf( "PASS 1: should find 1, found 1.\n" ) : printf( "FAIL 1: should find 1, found differently.\n" );
        $membersLocation->id == $result->searchHits[0]->valueObject->id ? printf( "PASS 2: Found 'Members' user group.\n" ) : printf( "FAIL 2: didn't find 'Members' user group.\n" );
    }

    public function testMoveSubtree( $searchHandler )
    {

        $repository = $this->getContainer()->get( 'ezpublish.api.repository' );
        $locationService = $repository->getLocationService();
        $contentService = $repository->getContentService();
        $searchService = $repository->getSearchService();

        $userService = $repository->getUserService();
        $adminUser = $userService->loadUser( 14 );
        $repository->setCurrentUser( $adminUser );

        $rootLocationId = 2;
        $membersContentId = 11;
        $adminsContentId = 12;
        $editorsContentId = 13;
        $membersContentInfo = $contentService->loadContentInfo($membersContentId);
        $adminsContentInfo = $contentService->loadContentInfo($adminsContentId);
        $editorsContentInfo = $contentService->loadContentInfo($editorsContentId);

        $membersLocations = $locationService->loadLocations( $membersContentInfo );
        $editorsLocations = $locationService->loadLocations( $editorsContentInfo );
        $membersLocation = $membersLocations[0];
        $editorsLocation = $editorsLocations[0];

        $newLocationStruct = $locationService->newLocationCreateStruct( $membersLocation->id );
        $adminsLocation = $locationService->createLocation($adminsContentInfo, $newLocationStruct);
        
        $searchHandler->commit();

        // Not found under Editors
        $criterion = new Criterion\ParentLocationId($editorsLocation->id);
        $query = new LocationQuery(array('filter' => $criterion));
        $result = $searchService->findLocations($query);

        //$this->assertEquals(0, $result->totalCount);
        $result->totalCount == 0 ? printf( "PASS 3: should find 0, found 0.\n" ) : printf( "FAIL 3: should find 0, found something instead.\n" );

        // Found under Members
        $criterion = new Criterion\ParentLocationId($membersLocation->id);
        $query = new LocationQuery(array('filter' => $criterion));
        $result = $searchService->findLocations($query);


        //$this->assertEquals(1, $result->totalCount);
        //$this->assertEquals($adminsLocation->id, $result->searchHits[0]->valueObject->id);
        $result->totalCount == 1 ? printf( "PASS 4: should find 1, found 1.\n" ) : printf( "FAIL 4: should find only 1, found another number.\n" );
        $adminsLocation->id == $result->searchHits[0]->valueObject->id ? printf( "PASS 5: found Administrators under Members.\n" ) : printf( "FAIL 5: didn't find Administrators under Members.\n" );


        // move location of 'Administrator users' group into 'Editors' group
        $locationService->moveSubtree($adminsLocation, $editorsLocation);

        $searchHandler->commit();


        // Found under Editors
        $criterion = new Criterion\ParentLocationId($editorsLocation->id);
        $query = new LocationQuery(array('filter' => $criterion));
        $result = $searchService->findLocations($query);

        //$this->assertEquals(1, $result->totalCount);
        //$this->assertEquals($adminsLocation->id, $result->searchHits[0]->valueObject->id);
        $result->totalCount == 1 ? printf( "PASS 6: should find 1, found 1.\n" ) : printf( "FAIL 6: should find only 1, found another number.\n" );
        $adminsLocation->id == $result->searchHits[0]->valueObject->id ? printf( "PASS 7: found Administrators under Editors.\n" ) : printf( "FAIL 7: didn't find Administrators under Editors.\n" );


        // Not found under Members
        $criterion = new Criterion\ParentLocationId($membersLocation->id);
        $query = new LocationQuery(array('filter' => $criterion));
        $result = $searchService->findLocations($query);

        //$this->assertEquals(0, $result->totalCount);
        $result->totalCount == 0 ? printf( "PASS 8: should find 0, found 0.\n" ) : printf( "FAIL 8: should find 0, found something instead.\n" );
    }
}


